@@ -51,29 +51,53 @@ LANGUAGES = {'afar': 'aa', 'abkhazian': 'ab', 'afrikaans': 'af',
 
 class PPD(object):
     """Represents a PostScript Description file."""
-    def __init__(self, ppd_file):
-        """Initializes a PPD object with the information at ppd_file string."""
-        filename = re.search('PCFileName:\s*"(.+)"', ppd_file)
-        language = re.search('LanguageVersion:\s*(.+)', ppd_file)
-        manufacturer = re.search('Manufacturer:\s*"(.+)"', ppd_file)
-        nickname = re.search('NickName:\s*"(.+)"', ppd_file)
-        deviceid = re.search('1284DeviceID:\s*"(.+)"', ppd_file)
-
-        try:
-            self.name = str.strip(filename.group(1))
-            self.language = LANGUAGES[str.strip(language.group(1)).lower()]
-            self.manufacturer = str.strip(manufacturer.group(1))
-            self.nickname = str.strip(nickname.group(1))
-            if deviceid:
-                self.deviceid = str.strip(deviceid.group(1))
-            else:
-                product = re.search('Product:\s*"\((.+)\)"', ppd_file)
-                product = str.strip(product.group(1))
-                self.deviceid = "MFG:%s;MDL:%s;" % (self.manufacturer, product)
-        except:
-            raise Exception, "Error parsing PPD file"
+    def __init__(self, filename, language, manufacturer, nickname, deviceid):
+        """Initializes a PPD object with the information passed."""
+        self.filename = filename
+        self.language = language
+        self.manufacturer = manufacturer
+        self.nickname = nickname
+        self.deviceid = deviceid
 
     def __str__(self):
-        return '"%s" %s "%s" "%s" "%s"' % (self.name, self.language,
+        return '"%s" %s "%s" "%s" "%s"' % (self.filename, self.language,
                                            self.manufacturer, self.nickname,
                                            self.deviceid)
+
+
+def parse(ppd_file, filename):
+    """Parses ppd_file and returns an array with the PPDs it found.
+
+    One ppd_file might result in more than one PPD. The rules are: return an
+    PPD for each "1284DeviceID" entry, and one for each "Product" line, if it
+    creates an unique (Manufacturer, Product) DeviceID.
+    """
+    language_re     = re.search('LanguageVersion:\s*(.+)', ppd_file)
+    manufacturer_re = re.search('Manufacturer:\s*"(.+)"', ppd_file)
+    nickname_re     = re.search('NickName:\s*"(.+)"', ppd_file)
+    deviceids       = re.findall('1284DeviceID:\s*"(.+)"', ppd_file)
+
+    try:
+        language = LANGUAGES[str.strip(language_re.group(1)).lower()]
+        manufacturer = str.strip(manufacturer_re.group(1))
+        nickname = str.strip(nickname_re.group(1))
+        ppds = []
+        models = []
+        if deviceids:
+            ppds = [PPD(filename, language, manufacturer, nickname, deviceid.strip()) for deviceid in deviceids]
+            for deviceid in deviceids:
+                models += re.findall(".*(?:MODEL|MDL):(.*?);.*", deviceid, re.I)
+
+        for product in re.findall('Product:\s*"\((.+)\)"', ppd_file):
+            product = str.strip(product)
+
+            # Don't add a new entry if there's already one for the same product model
+            if product in models:
+                continue
+
+            deviceid = "MFG:%s;MDL:%s;" % (manufacturer, product)
+            ppds += [PPD(filename, language, manufacturer, nickname, deviceid)]
+
+        return ppds
+    except:
+        raise Exception, ("Error parsing PPD file '%s'" % filename)
