@@ -1,11 +1,12 @@
 import os
 import stat
+import logging
 from optparse import OptionParser
 import archiver
 
 def parse_args():
     usage = "usage: %prog [options] ppds_directory"
-    version = "%prog 0.2.2\n" \
+    version = "%prog 0.4.1\n" \
               "Copyright (c) 2010 Vitor Baptista.\n" \
               "This is free software; see the source for copying conditions.\n" \
               "There is NO warranty; not even for MERCHANTABILITY or\n" \
@@ -27,15 +28,20 @@ def parse_args():
 
 
 def run():
+    logging.basicConfig(level=logging.DEBUG,
+                        format='%(asctime)s %(levelname)-8s %(message)s')
+
     (options, args) = parse_args()
     ppds_directory = args[0]
 
     archive = archiver.archive(ppds_directory)
 
+    logging.info('Writing archive to %s.' % options.output)
     output = open(options.output, "w+")
     output.write(archive)
     output.close()
 
+    logging.info('Setting %s\'s executable flag.' % options.output)
     execute_mode = stat.S_IEXEC | stat.S_IXGRP | stat.S_IXOTH
     mode = os.stat(options.output).st_mode | execute_mode
     os.chmod(options.output, mode)
